# Awesome WinUI
A collection of awesome resources for WinUI / Windows developers.
[<img src="https://microsoft.github.io/microsoft-ui-xaml/img/winui-logo.png" align="right" width="170">](https://microsoft.github.io/microsoft-ui-xaml/)


[![Awesome](https://awesome.re/badge.svg)](https://awesome.re)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)
![last commit](https://img.shields.io/github/last-commit/scottkuhl/awesome-winui?cacheSeconds=86400)

We use Releases to alert of new content, add a **Watch** to **Releases only** to get regular updates of new content.

If you are looking for WinUI 3.0 content look for this badge: [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/)

Contributions are always welcome! Please take a look at the [contribution guidelines](https://github.com/scottkuhl/awesome-winui/blob/master/contributing.md) pages first.

# Upcoming Events

**Stay Tuned**

Future events in 2021 will be listed here as soon as they are announced.

## Introduction

### What is WinUI?

[WinUI](https://microsoft.github.io/microsoft-ui-xaml/) is a user interface layer that contains modern controls and styles for building Windows apps. As the native UI layer in Windows it embodies Fluent Design, giving each Windows app the polished feel that customers expect.

As of version 3.0 it has been decoupled from the underlying Windows development platforms such as WinForms, WPF and UWP.

### What We Track

This list focuses on libraries, articles, tutorials, books and other resources for building Windows application with WinUI.  Older content can be found in the Archive folder.

## Contents
* [General](#general)
* [Libraries](#libraries)
* [Tooling](#tooling)
* [Sample Apps](#sample-apps)
* [Education](#education)
* [Channels](#channels)
* [Events](#events)
* [Podcasts](#podcasts)
* [Screencasts](#screencasts)
* [Articles](#articles)

## General

* [WinUI](https://microsoft.github.io/microsoft-ui-xaml/) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/microsoft-ui-xaml?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/microsoft-ui-xaml?cacheSeconds=86000) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) Official documentation of WinUI.  A [demo app](https://github.com/microsoft/Xaml-Controls-Gallery/tree/winui3preview) is also available.

* [Fluent Design System](https://www.microsoft.com/design/fluent/#/windows) - Make your apps feel as though they were designed with every Windows device in mind—PCs, phones, Xbox One, HoloLens, and more. Find the documentation, tools, and samples you need to get your apps published to the Microsoft Store.

* [Microsoft Learn](https://docs.microsoft.com/en-us/learn/) - Whether you're just starting or an experienced professional, Microsoft's hands-on approach helps you arrive at your goals faster, with more confidence and at your own pace.

* [UWP Community](https://uwpcommunity.com/) - The homepage for the unofficial Discord server.

* [Universal Windows Platform](https://docs.microsoft.com/en-us/windows/uwp/) - Official documentation of Universal Windows Platform, from Microsoft.

* [Windows Forms](https://docs.microsoft.com/en-us/dotnet/framework/winforms/) - Official documentation of Windows Forms, from Microsoft.

* [Windows Presentation Foundation](https://docs.microsoft.com/en-us/dotnet/framework/wpf/) - Official documentation of Windows Presentation Foundation, from Microsoft.

* [Themes of .NET](https://themesof.net/) - Track overall themes and underlying epics and user stories planned for the next major version of .NET.

## Libraries

* [Uno Platform](https://github.com/unoplatform/uno) - ![GitHub stars](https://img.shields.io/github/stars/unoplatform/uno?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/unoplatform/uno?cacheSeconds=86000) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) The Uno Platform is a Universal Windows Platform Bridge that allows UWP-based code (C# and XAML) to run on iOS, Android, macOS, and WebAssembly.

* [Windows Community Toolkit](https://github.com/windows-toolkit/WindowsCommunityToolkit/) - ![GitHub stars](https://img.shields.io/github/stars/windows-toolkit/WindowsCommunityToolkit?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/windows-toolkit/WindowsCommunityToolkit?cacheSeconds=86000) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) The Windows Community Toolkit has been working alongside the WinUI team to also make sure the Toolkit works on WinUI 3! We're happy to announce that we're also shipping a preview of the toolkit that works on top of this WinUI 3 Preview 1 the same day!

* [Project Reunion](https://github.com/microsoft/ProjectReunion) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/ProjectReunion?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/ProjectReunion?cacheSeconds=86000) Project Reunion is our vision for unifying and evolving the Windows developer platform to make it easier to build great apps that work across all the Windows 10 versions and devices people use.

* [Windows task snippets](https://github.com/microsoft/Windows-task-snippets) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/Windows-task-snippets?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/Windows-task-snippets?cacheSeconds=86000) This repo collects snippets of ready-to-use code that accomplish small but useful tasks of interest to Universal Windows Platform (UWP) app developers. These snippets represent simple solutions to common problems, and simple recipes to help you implement new app features.

* [Template10.Validation](https://github.com/Windows-XAML/Template10.Validation) - ![GitHub stars](https://img.shields.io/github/stars/Windows-XAML/Template10.Validation?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Windows-XAML/Template10.Validation?cacheSeconds=86000) These validation libraries provide UWP developers a comprehensive solution to data validation that solves problems in a realistic and usable way. The associated sample application demonstrates the use and syntax. 

* [Windows Graph Controls](https://github.com/windows-toolkit/Graph-Controls) - ![GitHub stars](https://img.shields.io/github/stars/windows-toolkit/Graph-Controls?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/windows-toolkit/Graph-Controls?cacheSeconds=86000) This is a sub-repo for the Windows Community Toolkit focused on Microsoft Graph providing a set of Helpers and Controls for development on Windows 10 with .NET.

* [Legerity](https://github.com/MADE-Apps/legerity) - ![GitHub stars](https://img.shields.io/github/stars/MADE-Apps/legerity?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/MADE-Apps/legerity?cacheSeconds=86000) Legerity is a framework for speeding up the development of automated UI testing with Appium and .NET!

* [Yugen Toolkit](https://github.com/emiliano84/Yugen.Toolkit) - ![GitHub stars](https://img.shields.io/github/stars/emiliano84/Yugen.Toolkit?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/emiliano84/Yugen.Toolkit?cacheSeconds=86000) The Toolkit is a collection of helper functions, custom controls, and app services. It helps develop common task for UWP apps.

* [Syncfusion WinUI](https://www.telerik.com/winui) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) - The Syncfusion WinUI toolkit includes feature-rich WinUI controls like DataGrid, Charts, TreeView, and more, that embodies Fluent Design for building modern and seamless Windows apps. **[$]**

* [Telerik UI for WinUI](https://www.telerik.com/winui) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) - Telerik UI for WinUI is an early experiment for the UI component suite, targeting WinUI 3.0. Its purpose is to make the development of modern and feature-rich applications faster and easier. **[$]**


## Tooling

* [Windows Template Studio](https://github.com/Microsoft/WindowsTemplateStudio) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/WindowsTemplateStudio?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/WindowsTemplateStudio?cacheSeconds=86000) Windows Template Studio (WinTS) is a Visual Studio 2019 Extension that accelerates the creation of new Universal Windows Platform (UWP) and Windows Presentation Foundation (WPF .NET Core 3.1) apps using a wizard-based experience. The resulting project is well-formed, readable code that incorporates great development features while implementing proven patterns and best practices. Sprinkled throughout the generated code we have links Docs, Stack Overflow and blogs to provide useful insights. WinTS supports creating UWP apps in C# or VB.Net and WPF (.NET Core 3.1) apps in C#.

* [Template10](https://github.com/Windows-XAML/Template10) - ![GitHub stars](https://img.shields.io/github/stars/Windows-XAML/Template10?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Windows-XAML/Template10?cacheSeconds=86000) Template 10 is a set of Visual Studio project templates. They sling-shot developer productivity by getting ~80% of the boilerplate stuff delivered in the template - things like navigation, suspension, and even a Hamburger control.

* [Fluent XAML Theme Editor](https://github.com/microsoft/fluent-xaml-theme-editor) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/fluent-xaml-theme-editor?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/fluent-xaml-theme-editor?cacheSeconds=86000) This repo contains the full solution and source code to the Fluent XAML Theme Editor - a tool that helps demonstrate the flexibility of the Fluent Design System as well as supports the app development process by generating XAML markup for our ResourceDictionary framework used in Universal Windows Platform (UWP) applications.

* [Rapid XAML Toolkit](https://github.com/mrlacey/Rapid-XAML-Toolkit) - ![GitHub stars](https://img.shields.io/github/stars/mrlacey/Rapid-XAML-Toolkit?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/mrlacey/Rapid-XAML-Toolkit?cacheSeconds=86000) This is a collection of tools for making it easier for developers to work with XAML (UWP, WPF, and Xamarin.Forms).

* [Windows app bootstrap template](https://github.com/dpaulino/windows-app-bootstrap) - ![GitHub stars](https://img.shields.io/github/stars/dpaulino/windows-app-bootstrap?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/dpaulino/windows-app-bootstrap?cacheSeconds=86000) A simple template repository you can use to fast track your new modern Windows app.

* [UWP Essentials](https://github.com/mrlacey/UwpEssentials) - ![GitHub stars](https://img.shields.io/github/stars/mrlacey/UwpEssentials?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/mrlacey/UwpEssentials?cacheSeconds=86000) The easiest way to set up Visual Studio for the ultimate UWP development experience.

* [Character Map UWP](https://www.microsoft.com/en-us/p/character-map-uwp/9wzdncrdxf41) - A modern, native UWP replacement for the Win32 Character Map and Windows Font Viewer with flawless high DPI and touch support.

* [UWP Resources Gallery](https://www.microsoft.com/en-us/p/uwp-resources-gallery/9pjjl433vx9r) - This app aims to provide an interactive demo of common UWP resources such as the Segoe MDL2 icons, system colors and system brushes.

* [Visual Asset Generator](https://www.microsoft.com/en-us/p/visual-asset-generator/9mz6qrqtdkf2) - An app designed to make creating Icons and Visual Assets for UWP apps a breeze.

* [XAML Studio](https://www.microsoft.com/en-us/garage/profiles/xaml-studio/) - XAML Studio, a Microsoft Garage project will help you rapidly prototype UWP XAML that can be easily copied into your app in Visual Studio. XAML Studio lets you preview your XAML code in real-time and interact with the result just like it was running in your own app!

## Sample Apps

* [Universal Windows Platform (UWP) app samples](https://github.com/microsoft/Windows-universal-samples) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/Windows-universal-samples?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/Windows-universal-samples?cacheSeconds=86000) This repo contains the samples that demonstrate the API usage patterns for the Universal Windows Platform (UWP) in the Windows Software Development Kit (SDK) for Windows 10. These code samples were created with the Universal Windows Platform templates available in Visual Studio, and are designed to run on desktop, mobile, and future devices that support the Universal Windows Platform.

* [Windows Composition Samples](https://github.com/microsoft/WindowsCompositionSamples) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/WindowsCompositionSamples?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/WindowsCompositionSamples?cacheSeconds=86000) This is the place for the latest code samples, demos, and developer feedback around building beautiful and engaging Universal Windows Platform apps. This repo focuses on the platform-building blocks that make up the Fluent Design System, with emphasis on creating UI using APIs in the Windows.UI.Composition namespace. The code samples and demos in this repo are targeted at developers who are interested in experimenting, building, and providing feedback on the latest flighting Windows UI APIs.

* [XAML Controls Gallery](https://github.com/microsoft/Xaml-Controls-Gallery/) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/Xaml-Controls-Gallery?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/Xaml-Controls-Gallery?cacheSeconds=86000) Shows all of the XAML controls in an interactive format. This app is the interactive companion to the Fluent Design Guidelines and shows the usage of both UWP Xaml APIs and Windows UI Toolkit APIs.

* [UWP Experiences - app samples](https://github.com/microsoft/uwp-experiences) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/uwp-experiences?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/uwp-experiences?cacheSeconds=86000) The UWP App Experiences are beautiful, cross device, feature rich and functional app samples built to demonstrate realistic app scenarios on the UWP platform across desktop, Xbox, mobile, and more. Besides being open source on GitHub, each sample is published to the Windows Store for easier access for developers and each is accompanied with at least one blog post and short overview video.

* [XAML VanArsdel Inventory Sample](https://github.com/microsoft/InventorySample) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/InventorySample?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/InventorySample?cacheSeconds=86000) This repo showcases a sample Windows 10 application (using the Universal Windows Platform) focused in Line of Business scenarios, showing how to use the latest Windows capabilities in Desktop applications. The sample is based around creating and managing customer, orders, and products for the fictitious company VanArsdel.

* [BuildCast Video Player UWP Sample](https://github.com/Microsoft/BuildCast) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/BuildCast?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/BuildCast?cacheSeconds=86000) BuildCast is an end-to-end sample built to showcase the Microsoft Fluent Design System as well as other capabilities of the Universal Windows Platform. It permits browsing, downloading and playback of select video podcasts including a sampling of the most popular ones from Channel 9 as well as some popular Windows tech enthusiast feeds. It has other features such as ink notes, bookmarks and remote playback. This sample was initially shown and discussed at the 2017 Build conference during the Build Amazing Apps with Fluent Design talk.

* [Customers Orders Database sample](https://github.com/Microsoft/Windows-appsample-customers-orders-database) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-customers-orders-database?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-customers-orders-database?cacheSeconds=86000) A UWP (Universal Windows Platform) sample app showcasing features useful to enterprise developers, like Azure Active Directory (AAD) authentication, UI controls (including a data grid), Sqlite and SQL Azure database integration, Entity Framework, and cloud API services. The sample is based around creating and managing customer accounts, orders, and products for the fictitious company Contoso.

* [RSS Reader sample](https://github.com/Microsoft/Windows-appsample-rssreader) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-rssreader?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-rssreader?cacheSeconds=86000) A mini-app for retrieving RSS feeds and viewing articles, showing MVVM and design best practices. Users can specify the URL of a feed, view articles in a WebView control, and save favorite articles to local storage.

* [Lunch Scheduler app](https://github.com/Microsoft/Windows-appsample-lunch-scheduler) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-lunch-scheduler?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-lunch-scheduler?cacheSeconds=86000) Lunch Scheduler is a Universal Windows Platform (UWP) sample that schedules lunches with your friends and coworkers. You can invite friends to a restaurant of interest and the app takes care of the lunch management for all involved parties.

* [Family Notes sample](https://github.com/Microsoft/Windows-appsample-familynotes) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-familynotes?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-familynotes?cacheSeconds=86000) A mini-app that explores different input modalities and scenarios of user awareness. A bulletin-board app that allows family members to leave notes for each other on a common PC/tablet just like they would on a bulletin board. Using text, speech, ink, or pictures, a user can create a note and tag it for another user. Later when that other user approaches the PC/Tablet, the app uses imaging APIs and the Microsoft Cognitive Services (Face API) to detect their presence and display the notes that have been left for them, effectively filtering based on facial recognition. While the app is open, users can naturally interact with it using speech (“Add note for Bob”). If the app isn’t open, a user can easily launch it and interact with it using Cortana.

* [Coloring Book sample](https://github.com/Microsoft/Windows-appsample-coloringbook) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-coloringbook?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-coloringbook?cacheSeconds=86000) A mini-app that demonstrates the versatility of Windows Ink (including the Windows Ink Toolbar) and radial controller (for Wheel devices such as the Surface Dial) features.

* [VanArsdel UWP Sample](https://github.com/microsoft/VanArsdel) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/VanArsdel?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/VanArsdel?cacheSeconds=86000) VanArsdel is an end-to-end sample built to showcase the Microsoft Fluent Design System as well as other capabilities of the Universal Windows Platform. It allows the user to browse the virtual "store" of lamps that can be organized and decorated.

* [Photo Editor C++/WinRT sample](https://github.com/Microsoft/Windows-appsample-photo-editor) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-photo-editor?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-photo-editor?cacheSeconds=86000) The Photo Editor application is a Universal Windows Platform (UWP) sample that showcases development with the C++/WinRT language projection. The sample application allows you to retrieve photos from the Pictures library, and then edit the selected image with assorted photo effects. In the sample's source code, you'll see a number of common practices—such as data binding, and asynchronous actions and operations—performed using the C++/WinRT projection.

* [Photo Lab sample](https://github.com/Microsoft/Windows-appsample-photo-lab) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-photo-lab?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-photo-lab?cacheSeconds=86000) A mini-app for viewing and editing image files, demonstrating XAML layout, data binding, and UI customization features for Universal Windows Platform (UWP) apps.

* [MVVM Toolkit Samples](https://github.com/windows-toolkit/MVVM-Samples) - ![GitHub stars](https://img.shields.io/github/stars/windows-toolkit/MVVM-Samples?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/windows-toolkit/MVVM-Samples?cacheSeconds=86000) The Microsoft.Toolkit.Mvvm package is a modern, fast, and modular MVVM library. It is built around the following principles: Platform and Runtime Independent, Simple to pick-up and use, À la carte, Reference Implementation.

* [UWP Demo for Insider Dev Tour 2019](https://github.com/microsoft/InsiderDevTourDemos19/tree/master/Sessions/ui) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/InsiderDevTourDemos19?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/InsiderDevTourDemos19?cacheSeconds=86000) This repo contains a demo UWP app that is built for demostrating rich controls and libraries from Windows UI Library and Windows Community Toolkit.

* [Hue Lights sample](https://github.com/Microsoft/Windows-appsample-huelightcontroller) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-huelightcontroller?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-huelightcontroller?cacheSeconds=86000) A mini-app that explores integrating Windows features with intelligent home automation. Specifically, it shows how you can use Cortana and Bluetooth Low Energy (Bluetooth LE) to create an interactive experience with the Phillips Hue Lights (a Wi-Fi enabled lighting system).

* [Quiz Game Sample](https://github.com/microsoft/Windows-appsample-remote-system-sessions) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/Windows-appsample-remote-system-sessions?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/Windows-appsample-remote-system-sessions?cacheSeconds=86000) A pub-style trivia game sample for the Universal Windows Platform (UWP) demonstrating the Remote System Session API (part of the Project Rome platform).

* [Uno Samples](https://github.com/unoplatform/Uno.Samples) - ![GitHub stars](https://img.shields.io/github/stars/unoplatform/Uno.Samples?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/unoplatform/Uno.Samples?cacheSeconds=86000) This repository provides simple to-the-point samples for features of the Uno platform.

* [Contoso Insurance UWP App](https://github.com/microsoft/WDD-Spring-2018) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/WDD-Spring-2018?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/WDD-Spring-2018?cacheSeconds=86000) This UWP app was designed to showcase how Fluent Design, Windows Timeline and Adaptive Cards work together on the Windows Developer Day 2018.

* [Fluent Store](https://github.com/yoshiask/FluentStore) - ![GitHub stars](https://img.shields.io/github/stars/yoshiask/FluentStore?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/yoshiask/FluentStore?cacheSeconds=86000) A Fluent, native, and open-source alternative to the Microsoft Store app.

* [Ch9](https://github.com/unoplatform/Uno.Ch9) - ![GitHub stars](https://img.shields.io/github/stars/unoplatform/Uno.Ch9?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/unoplatform/Uno.Ch9?cacheSeconds=86000) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) Ch9 is a demo app which showcases the power of using WinUI and Uno Platform for developing single-codebase, cross-platform applications for Windows, iOS, Android and WebAssembly. It uses the publicly-available video feed from Microsoft's Channel 9 for content.  The app is also available in App Stores ([Microsoft](https://www.microsoft.com/store/productId/9NL3GNG31TMK), [Apple](https://apps.apple.com/us/app/ch9/id1512235875?ls=1), [Google](https://play.google.com/store/apps/details?id=uno.platform.ch9&hl=en)).

* [UWP IEXCloud Sample](https://github.com/XamlBrewer/UWP-IEXCloud-Sample) - ![GitHub stars](https://img.shields.io/github/stars/XamlBrewer/UWP-IEXCloud-Sample?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/XamlBrewer/UWP-IEXCloud-Sample?cacheSeconds=86000) An attempt to build a representative and useful WinUI reference app.  The [announcement article](https://xamlbrewer.wordpress.com/2020/06/16/a-winui-2-reference-app/) can be found here.

## Education

Education are listed by newest date first.

* Learn WinUI 3.0 [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) - (Fall 2020) - Alvin Ashcraft, Packt Publishing - [Early announcement](https://www.winui.tips/2020/02/learn-winui-30-my-new-book-to-be.html).
* [Introduction to Uno Platform](https://www.udemy.com/course/introduction-to-uno-platform/?referralCode=C9FE308096EADFB5B661) - (August 2020) - Christian Findlay, Udemy - Build Single-Source WebAssembly, Mobile and Desktop Apps with C#.

## Channels

[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/8d74b374-2335-448d-9e3d-f7f27841ef04-profile_image-150x150.png">](https://www.twitch.tv/xamlllama) 
[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/23bc51a7-bf03-41f5-9e98-9f5ed9d2ecc0-profile_image-150x150.png">](https://www.twitch.tv/visualstudio) 
[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/e98df394-1bee-43c0-9f5f-78a63148a84b-profile_image-150x150.png">](https://www.twitch.tv/dotnetnorthlive) 
[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/9590f1ae-c091-4bba-b07c-2bbc3400ac28-profile_image-150x150.png">](https://www.twitch.tv/martinzikmund) 
[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/6c80c1db-783f-4409-b15b-da22af24b6c6-profile_image-150x150.png">](https://www.twitch.tv/jeromelaban) 

## Events

Events are listed by newest date first.

## Podcasts

Podcasts are listed by newest date first.

## Screencasts

Screencasts are listed by newest date first.

All .NET Community Standups are listed on [Microsoft .NET Community Standups](https://dotnet.microsoft.com/platform/community/standup).

**WinUI Community Call Occurs the 3rd Wednesday of every month at 9:00AM PDT**

[<img src="https://github.com/scottkuhl/awesome-winui/blob/main/Images/Community%20Call.png?raw=true">](https://www.youtube.com/channel/UCzLbHrU7U3cUDNQWWAqjceA)

* [Building Powerful Native Application Experiences](https://www.youtube.com/watch?v=C82wswLDdSM) - (January 4, 2021) - ![duration](https://img.shields.io/badge/Duration:%20-45%20min-%230094FF?cacheSeconds=maxAge&logo=youtube) In this session, we learn about getting started for developing windows 10 applications, packaging your applications with MSIX, some latest enhancements to command line tools for developers building on windows, and lastly, we hear about the new platform 'Windows on ARM'

## Articles

Articles are listed by newest date first.

* [Introducing Syncfusion Ribbon for WinUI](https://www.syncfusion.com/blogs/post/introducing-syncfusion-ribbon-for-winui.aspx) - (January 7, 2021) - In order to have good flow in your work, you should optimize all possible operations using a ribbon control. A ribbon control is a tool that allows you to group tasks together so they can be performed in sequence.

* [What’s New in 2020 Volume 4: WinUI](https://www.syncfusion.com/blogs/post/whats-new-in-2020-volume-4-winui.aspx) - (January 4, 2021) - We at Syncfusion are glad to announce the last major release of this year, Essential Studio 2020 Volume 4. This is the second major release for Syncfusion Essential Studio for WinUI. If you are new to the WinUI platform, check out our previous blog post about the features included in the first release.

* [Introducing the WinUI InfoBar control](https://xamlbrewer.wordpress.com/2021/01/04/introducing-the-winui-infobar-control/) - (January 4, 2021) - According to its roadmap WinUI 3.0 is currently focusing on Win32 desktop applications and .NET 5. In mean time WinUI 2.x keeps on evolving, bringing XAML features and controls for UWP. One of these new controls is the InfoBar control which was released as a component of WinUI 2.5.  In its original proposal we read that Microsoft was looking for a uniform way to display “long-lived app-wide status messages for scenarios such as updates available or errors that may occur which prevent the user from experiencing an app or its features working as intended“.
